#!/usr/bin/env python
# -*- coding: utf8 -*-
from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement
from .middlewares import get_request_id

app_requires = [
    "django_middleware_global_request",
]

app_middleware_requires = [
    "django_middleware_global_request.middleware.GlobalRequestMiddleware",
    "django_middleware_request_id.middlewares.DjangoMiddlewareRequestId",
]

app_setting_callbacks = [
    "django_middleware_request_id.log_filters.add_request_id_log_filter",
]



#!/usr/bin/env python
# -*- coding: utf8 -*-
from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement

from django.apps import AppConfig

class DjangoMiddlewareRequestIdConfig(AppConfig):
    name = 'django_middleware_request_id'



#!/usr/bin/env python
# -*- coding: utf8 -*-
from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement

import uuid
from django.conf import settings
from django_middleware_global_request.middleware import get_request

DJANGO_REQUEST_ID_ATTRIBUTE = getattr(settings, "DJANGO_REQUEST_ID_ATTRIBUTE", "_request_id")
DJANGO_REQUEST_ID_HEADER = getattr(settings, "DJANGO_REQUEST_ID_HEADER", "HTTP_X_REQUEST_ID")

class DjangoMiddlewareRequestId(object):

    def __init__(self, get_response):
        self.get_response = get_response
    
    def __call__(self, request):
        request_id = request.META.get(DJANGO_REQUEST_ID_HEADER, None)
        if not request_id:
            request_id = uuid.uuid4().hex
        setattr(request, DJANGO_REQUEST_ID_ATTRIBUTE, request_id)
        response = self.get_response(request)
        return response


def get_request_id():
    """Get current request id. If NOT called from the request, e.g. call form unittest, returns empty string.
    """
    request = get_request()
    request_id = getattr(request, DJANGO_REQUEST_ID_ATTRIBUTE, "")
    if request and (not request_id):
        request_id = uuid.uuid4().hex
        setattr(request, DJANGO_REQUEST_ID_ATTRIBUTE, request_id)
    return request_id



#!/usr/bin/env python
# -*- coding: utf8 -*-
from __future__ import absolute_import, division, generators, nested_scopes, print_function, unicode_literals, with_statement

import logging
from django.conf import settings
from .middlewares import get_request_id

DJANGO_REQUEST_ID_LOG_ID = getattr(settings, "DJANGO_REQUEST_ID_LOG_ID", "request_id")

class RequestIdLogFilter(logging.Filterer):
    def filter(self, record):
        setattr(record, DJANGO_REQUEST_ID_LOG_ID, get_request_id())
        return True

def add_request_id_log_filter(globals):
    """Fix LOGGING in pro/settings.py.
    """
    LOGGING = globals.get("LOGGING", {})
    if LOGGING:
        filters = LOGGING.get("filters", None)
        if filters is None:
            LOGGING["filters"] = {}
            filters = LOGGING["filters"]
        if not DJANGO_REQUEST_ID_LOG_ID in filters:
            filters[DJANGO_REQUEST_ID_LOG_ID] = {
                "()": "django_middleware_request_id.log_filters.RequestIdLogFilter",
            }
        handlers = LOGGING.get("handlers", None)
        if handlers is None:
            LOGGING["handlers"] = {}
            handlers = LOGGING["handlers"]
        for _, handler_config in handlers.items():
            if not "filters" in handler_config:
                handler_config["filters"] = []
            if not DJANGO_REQUEST_ID_LOG_ID in handler_config["filters"]:
                handler_config["filters"].append(DJANGO_REQUEST_ID_LOG_ID)
